@@ -13,19 +13,13 @@ MEM_COMMIT = 0x1000
 MEM_RESERVE = 0x2000
 PAGE_READWRITE = 0x4
 
-# Temporary manual definitions
-
-class IO_APC_ROUTINE:
-    pass
-
-class IO_STATUS_BLOCK:
-    pass
-
-class LARGE_INTEGER:
-    pass
-
-class UNICODE_STRING:
-    pass
+# ntioapi.h
+FILE_SUPERSEDED = 0x00000000
+FILE_OPENED = 0x00000001
+FILE_CREATED = 0x00000002
+FILE_OVERWRITTEN = 0x00000003
+FILE_EXISTS = 0x00000004
+FILE_DOES_NOT_EXIST = 0x00000005
 
 def round_to_pages(size):
     return (size + 0xFFF) & 0xFFFFFFFFFFFFF000
